@@ -3,7 +3,7 @@ group_bootstrap <- function(x, i, j, indent = 1, ...) {
   out <- x
   # columns first to count headers properly
   if (!is.null(j)) {
-    out <- group_bootstrap_col(out, i = i, j = j, ...)
+    out <- group_bootstrap_col(out, j = j, ...)
   }
   if (!is.null(i)) {
     out <- group_bootstrap_row(out, i = i, j = j, indent = indent, ...)
@@ -12,9 +12,10 @@ group_bootstrap <- function(x, i, j, indent = 1, ...) {
 }
 
 
-group_bootstrap_col <- function(x, i, j, ...) {
+group_bootstrap_col <- function(x, j, ihead, ...) {
 
   m <- meta(x)
+
   out <- strsplit(x, "\\n")[[1]]
   header <- NULL
 
@@ -26,18 +27,27 @@ group_bootstrap_col <- function(x, i, j, ...) {
   max_col <- sapply(j, max)
   idx <- order(max_col)
   j <- j[idx]
-  j <- lapply(names(j), function(n) sprintf(
+  jstring <- lapply(names(j), function(n) sprintf(
     '<th scope="col" align="center" colspan=%s>%s</th>',
     max(j[[n]]) - min(j[[n]]) + 1, n))
-  j <- paste(unlist(j), collapse = "\n")
+  jstring <- paste(unlist(jstring), collapse = "\n")
+  jstring <- sprintf("<tr>\n%s\n</tr>", jstring)
 
   idx <- grep("<thead>", out, fixed = TRUE)[1]
-  out <- c(out[seq_len(idx)], j, out[(idx + 1):length(out)])
+  out <- c(out[seq_len(idx)], jstring, out[(idx + 1):length(out)])
 
   out <- paste(out, collapse = "\n")
 
   class(out) <- class(x)
   attr(out, "tinytable_meta") <- m
+
+  out <- style_bootstrap(out, i = ihead, align = "c")
+
+  # midrule on numbered spans (not full columns of body)
+  jnames <- names(j)
+  jnames <- seq_along(jnames)[trimws(jnames) != ""]
+  out <- style_bootstrap(out, i = ihead, j = jnames, line = "b", line_width = .05, line_color = "#d3d8dc")
+
   return(out)
 }
 
